"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.StrokeAnimator = void 0;
var _react = require("react");
var _reactNativeReanimated = require("react-native-reanimated");
var _AnimatedPath = _interopRequireDefault(require("../components/AnimatedPath"));
var _geometry = require("../geometry");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const StrokeAnimator = /*#__PURE__*/(0, _react.forwardRef)(function StrokeAnimator(_ref, ref) {
  let {
    stroke,
    strokeColor,
    strokeWidth
  } = _ref;
  const progress = (0, _reactNativeReanimated.useSharedValue)(0);
  (0, _react.useImperativeHandle)(ref, () => ({
    reset: () => {
      progress.value = (0, _reactNativeReanimated.withDelay)(150, (0, _reactNativeReanimated.withTiming)(0, {
        duration: 0,
        easing: _reactNativeReanimated.Easing.ease
      }));
    },
    animate: params => {
      const {
        duration,
        delay,
        onComplete
      } = params;
      const onCompleteCallback = () => onComplete?.();
      const strokeIn = (0, _reactNativeReanimated.withTiming)(1, {
        duration,
        easing: _reactNativeReanimated.Easing.linear
      }, () => (0, _reactNativeReanimated.runOnJS)(onCompleteCallback)());
      progress.value = delay ? (0, _reactNativeReanimated.withDelay)(delay, strokeIn) : strokeIn;
    }
  }));
  const path = (0, _react.useMemo)(() => {
    const extendedMaskPoints = (0, _geometry.extendStart)(stroke.points, strokeWidth / 2);
    return (0, _geometry.getPathString)(extendedMaskPoints);
  }, [stroke.points, strokeWidth]);
  const pathLength = stroke.getLength() + strokeWidth / 2;
  return /*#__PURE__*/React.createElement(AnimatedStroke, {
    clipPath: `url(#clip.${stroke.strokeNum})`,
    progress: progress,
    d: path,
    color: strokeColor,
    pathLength: pathLength
  });
});
exports.StrokeAnimator = StrokeAnimator;
function AnimatedStroke(_ref2) {
  let {
    d,
    progress,
    clipPath,
    color,
    pathLength
  } = _ref2;
  const ref = (0, _react.useRef)(null);
  const animatedProps = (0, _reactNativeReanimated.useAnimatedProps)(() => {
    // Sometimes the progress value can be slightly out of bounds due to floating point errors
    const clampedProgress = Math.min(Math.max(progress.value, 0), 1);
    return {
      strokeDashoffset: pathLength * (1 - clampedProgress),
      // Ease out the stroke opacity
      strokeOpacity: clampedProgress < 0.01 ? clampedProgress * 2 : 1
    };
  });
  return /*#__PURE__*/React.createElement(_AnimatedPath.default, {
    ref: ref,
    animatedProps: animatedProps,
    d: d,
    stroke: color,
    clipPath: clipPath,
    strokeWidth: 180,
    strokeLinecap: "round",
    fill: "none",
    strokeDasharray: `${pathLength},${pathLength}`
  });
}
//# sourceMappingURL=StrokeAnimator.js.map